aboutsummaryrefslogtreecommitdiff
path: root/src/processor/process_state.cc
diff options
context:
space:
mode:
Diffstat (limited to 'src/processor/process_state.cc')
-rw-r--r--src/processor/process_state.cc5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/processor/process_state.cc b/src/processor/process_state.cc
index 6c3a6567..fae66776 100644
--- a/src/processor/process_state.cc
+++ b/src/processor/process_state.cc
@@ -57,9 +57,10 @@ void ProcessState::Clear() {
}
threads_.clear();
system_info_.Clear();
// modules_without_symbols_ DOES NOT owns the underlying CodeModule pointers.
// Just clear the vector.
modules_without_symbols_.clear();
+ modules_with_corrupt_symbols_.clear();
delete modules_;
modules_ = NULL;
}
@@ -57,9 +57,10 @@ void ProcessState::Clear() {
threads_.clear();
system_info_.Clear();
- // modules_without_symbols_ DOES NOT owns the underlying CodeModule pointers.
- // Just clear the vector.
+ // modules_without_symbols_ and modules_with_corrupt_symbols_ DO NOT own
+ // the underlying CodeModule pointers. Just clear the vectors.
modules_without_symbols_.clear();